#[non_exhaustive]pub enum ActionPromiseState {
Claimed {
claim: String,
},
Pending {
retry_after_ms: u64,
},
Complete {
prediction: ActionPrediction,
},
}Expand description
State returned when a client joins an invocation-wide promise.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Claimed
This client owns the lease and should perform the compilation.
Pending
Another client owns the lease; retry after the stated delay.
Complete
The owner published a prediction through which this client can restore.
Fields

prediction: ActionPredictionPrediction for reconstructing and looking up the final action key.
Implementations