pub struct ActionDiagnostic {
pub action: CacheDigest,
pub components: BTreeMap<String, CacheDigest>,
pub inputs: BTreeMap<String, CacheDigest>,
}Expand description
A privacy-preserving decomposition of an action key.
Values are content digests rather than source or environment contents. The names are enough to say what changed without copying secrets into session history.
Fields
action: CacheDigestComplete action-cache key.
components: BTreeMap<String, CacheDigest>Non-file key components, named for display.
inputs: BTreeMap<String, CacheDigest>Normalized input path to content digest.