AgentRequest

Enum AgentRequest 

pub enum AgentRequest {
Show 14 variants Hello { protocol: u8, client_version: String, }, FindBlob { digest: CacheDigest, }, FindBlobs { digests: Vec<CacheDigest>, }, StoreBlob { digest: CacheDigest, source: PathBuf, }, FindActionResult { action: CacheDigest, }, RecordActionHit { action: CacheDigest, restore: RestoreStats, }, RecordBypass { kind: String, }, RecordUnconsulted, RecordActionVerification { matched: bool, restore: RestoreStats, }, StoreActionResult { result: RemoteActionResult, }, FindActionPrediction { task: String, invocation: CacheDigest, }, RecordActionPrediction { task: String, prediction: ActionPrediction, }, FindExecutableIdentity { executable: PathBuf, environment: BTreeMap<String, Option<String>>, }, StoreExecutableIdentity { executable: PathBuf, environment: BTreeMap<String, Option<String>>, stdout: Vec<u8>, },
}
A request accepted by the task-scoped cache agent.

Variants



Hello

Fields

protocol: u8
client_version: String


FindBlob

Resolve a blob to a session-verified local CAS path.

Fields



FindBlobs

Resolve blobs to session-verified local CAS paths.

Fields

digests: Vec<CacheDigest>


StoreBlob

Fields

source: PathBuf


FindActionResult

Fields



RecordActionHit

Fields



RecordBypass

A compilation the adapter declined to cache, grouped by reason.

Fields

kind: String


RecordUnconsulted

A compilation the adapter could not look up, having no key to look up with. Distinct from a bypass: these are cached once compiled.



RecordActionVerification

Fields

matched: bool


StoreActionResult

Fields



FindActionPrediction

Fields

task: String
invocation: CacheDigest


RecordActionPrediction

Fields

task: String
prediction: ActionPrediction


FindExecutableIdentity

Fields

executable: PathBuf
environment: BTreeMap<String, Option<String>>


StoreExecutableIdentity

Fields

executable: PathBuf
environment: BTreeMap<String, Option<String>>
stdout: Vec<u8>